==> ng2-toastr-0.1.12.jar: META-INF/resources/webjars/ng2-toastr/0.1.12/src/toast-options.js <==
System.register(['angular2/core'], function(exports_1, context_1) {
    "use strict";
    var __moduleName = context_1 && context_1.id;
    var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
        var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
        if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
        else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
        return c > 3 && r && Object.defineProperty(target, key, r), r;
    };
    var __metadata = (this && this.__metadata) || function (k, v) {
        if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
    };
    var core_1;
    var ToastOptions;
    return {
        setters:[
            function (core_1_1) {
                core_1 = core_1_1;
            }],
        execute: function() {
            ToastOptions = (function () {
                function ToastOptions(options) {
                    Object.assign(this, options);
                }
                ToastOptions = __decorate([
                    core_1.Injectable(), 
                    __metadata('design:paramtypes', [Object])
                ], ToastOptions);
                return ToastOptions;
            }());
            exports_1("ToastOptions", ToastOptions);
        }
    }
});
//# sourceMappingURL=toast-options.js.map

==> ng2-toastr-0.2.0.jar: META-INF/resources/webjars/ng2-toastr/0.2.0/src/toast-options.js <==
System.register(['@angular/core'], function(exports_1, context_1) {
    "use strict";
    var __moduleName = context_1 && context_1.id;
    var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
        var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
        if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
        else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
        return c > 3 && r && Object.defineProperty(target, key, r), r;
    };
    var __metadata = (this && this.__metadata) || function (k, v) {
        if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
    };
    var core_1;
    var ToastOptions;
    return {
        setters:[
            function (core_1_1) {
                core_1 = core_1_1;
            }],
        execute: function() {
            ToastOptions = (function () {
                function ToastOptions(options) {
                    Object.assign(this, options);
                }
                ToastOptions = __decorate([
                    core_1.Injectable(), 
                    __metadata('design:paramtypes', [Object])
                ], ToastOptions);
                return ToastOptions;
            }());
            exports_1("ToastOptions", ToastOptions);
        }
    }
});
//# sourceMappingURL=toast-options.js.map
